C SOLUBLE B, SOLUBLE N AND BN CALCULATION FOR MAP PROJECT

C COPYRIGHT S.J.JONES & H.K.D.H. BHADESHIA (1996)

C           DEPT OF MATERIALS SCIENCE & METALLURGY
C           UNIVERSITY OF CAMBRIDGE
C           UNITED KINGDOM


C NB - THIS MODEL COULD EASILY BE ADAPTED TO WORK WITH OTHER 
C SOLUBILITY PRODUCTS EG. TITANIUM NITRIDE OR ALUMINIUM NITRIDE.

C****************************************************************************
C
C TEST PROGRAM:
C
       PROGRAM MAP_STEEL_SOL_BOR
       IMPLICIT NONE
C
       DOUBLE PRECISION BATM,BWT,NITATM,NIT2,NITWT,TEMPC,
     & BSOL,BWTSOL,NITSOL,NITWTSOL,NITB,BNIT
C
       READ(*,*) BATM,BWT,NITATM,NITWT,NIT2,TEMPC
C
       CALL MAP_STEEL_SOL_BOR(BATM,BWT,NITATM,NITWT,NIT2,
     & TEMPC,BSOL,BWTSOL,NITSOL,NITWTSOL,NITB,BNIT)
C
       WRITE(*,10) BSOL,BWTSOL,NITSOL,NITWTSOL,NITB,BNIT
10     FORMAT(E10.3,1X,E10.3,1X,E10.3,1X,E10.3,1X,E10.3,1X,E10.3)
C
       STOP
C
       END 
C
C****************************************************************************
C
         SUBROUTINE MAP_STEEL_SOL_BOR(BATM,BWT,NITATM,NITWT,NIT2,TEMPC,
     &   BSOL,BWTSOL,NITSOL,NITWTSOL,NITB,BNIT)
C
         IMPLICIT NONE
C
         DOUBLE PRECISION BATM,BWT,NITATM,NIT2,NITWT,TEMPC,
     &   BSOL,BWTSOL,NITSOL,NITWTSOL,NITB,BNIT,NIT3,CONST,
     &   BWTSOLMAX,SOLPRODCON,DIFBATMNIT2,SQROOT,NIT3A,NIT3B
C
C SOLUBLE B, SOLUBLE N AND BN CALCULATION
C
C NEW APPROACH JANUARY 12TH 1995
C
C TEST IF NO BORON AND NO AVAILABLE NITROGEN:
C
            IF(BATM.EQ.0.0. AND. NIT2.EQ.0.0 ) THEN
              NITB=0.0
              BWTSOL=0.0
              BSOL=0.0
              NITWTSOL=0.0
              NIT3=0.0
              GOTO 2
            ENDIF

C TEST IF NO BORON (ASSUME ALL AVAILABLE NITROGEN GOES INTO SOLUTION):

            IF(BATM.EQ.0.0) THEN
              NITB=0.0
              BWTSOL=0.0
              BSOL=0.0
              NITWTSOL=NIT2*NITWT/NITATM
              NIT3=NIT2
              GOTO 2
            ENDIF

C TEST IF NO AVAILABLE NITROGEN (ASSUME ALL BORON GOES INTO SOLUTION):

            IF(NIT2.EQ.0.0) THEN
              NITB=0.0
              BWTSOL=BWT
              BSOL=BATM
              NITWTSOL=0.0
              NIT3=0.0
              GOTO 2
            ENDIF

C SET SOLUBLE NITROGEN (NIT3) EQUAL TO NIT2 - ALL AVAILABLE AFTER
C TIN FORMATION:

           NIT3=NIT2

C SOLUBILITY PRODUCT FROM MAITREPIERRE ET AL. IN THEIR PAPER
C "STRUCTURE-PRPERTIES RELATIONSHIPS IN BORON STEELS" IN THE 
C PROCEEDINGS OF THE "BORON IN STEEL" CONFERENCE, MILWAUKEE,
C WISCONSIN, SEPTEMBER, 1979:

          BWTSOLMAX=(10.0**(0.20 - (6700.0/(TEMPC+273.00))))/
     &    (NIT3*NITWT/NITATM)

C IF BWTSOLMAX >= BWT THEN WE SHOULD ASSUME THAT ALL OF THE
C AVAILABLE NITROGEN (NIT2) AND ALL OF THE BORON (BWT) CAN
C REMAIN IN SOLUTION AT THE CHOSSEN TEMP (TEMPC = 940 DEGC).

        IF (BWTSOLMAX.GE.BWT) THEN
          BWTSOL=BWT
          BSOL=BATM
          NITWTSOL=NIT2*NITWT/NITATM
          NIT3=NIT2
          NITB=0.0
          GOTO 2
        ENDIF

C OR IF BWTSOLMAX < BWT

C THEN NIT2 AND BATM CANNOT ALL BE IN SOLUTION AT THE CHOSEN TEMP.

C THIS IS A SPECIAL CASE - STOICHIOMETRY: THE NO OF MOLES OF BORON
C AND NITROGEN THAT FORM BN SHOULD BE EQUAL. THUS THERE IS ONLY
C ONE UNKNOWN AND WE CAN AVOID USING AN ITERATIVE PROCEDURE.

C IE. FIND BSOL AND NIT3 WHICH SATISFIES:

C LOG10 (BSOL*BWT/BATM)(BSOL*NITWT/NITATM)=SOLUBILITY PRODUCT


        CONST=(BWT/BATM)*(NITWT/NITATM)

        SOLPRODCON=(10.0**(0.20-(6700.0/(TEMPC+273.00))))/(CONST)
        DIFBATMNIT2=BATM-NIT2
        SQROOT=( (DIFBATMNIT2**2.0)+(4.0*SOLPRODCON) )**(0.5)
        NIT3A=( (-1.0*DIFBATMNIT2)+SQROOT )/2.0
        NIT3B=( (-1.0*DIFBATMNIT2)-SQROOT )/2.0

        IF (NIT3A.LT.0.0) THEN 
         NIT3=NIT3B
        ELSE
         NIT3=NIT3A
        ENDIF

        BSOL=SOLPRODCON/NIT3


        BWTSOL=BSOL*BWT/BATM
        NITWTSOL=NIT3*NITWT/NITATM
        NITB=BATM-BSOL

        GOTO 2

C ASSIGN NIT3 TO NITSOL AND NITB TO BNIT

2       NITSOL=NIT3
        BNIT=NITB

C END OF SOLUBLE BORON CALCULATION

        RETURN

        END

C****************************************************************************
